# onshape_client
The Onshape REST API consumed by all clients.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.93
- Package version: 0.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import onshape_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import onshape_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import onshape_client
from onshape_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: OAuth2
configuration = onshape_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = onshape_client.AccountsApi(onshape_client.ApiClient(configuration))
aid = 'aid_example' # str | 
pid = 'pid_example' # str | 
cancel_immediately = False # bool |  (optional) (default to False)

try:
    # Cancel Recurring Subscription
    api_instance.cancel_purchase_new(aid, pid, cancel_immediately=cancel_immediately)
except ApiException as e:
    print("Exception when calling AccountsApi->cancel_purchase_new: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**cancel_purchase_new**](docs/AccountsApi.md#cancel_purchase_new) | **DELETE** /api/accounts/{aid}/purchases/{pid} | Cancel Recurring Subscription
*AccountsApi* | [**consume_purchase**](docs/AccountsApi.md#consume_purchase) | **POST** /api/accounts/purchases/{pid}/consume | Mark Purchase Consumed For User
*AccountsApi* | [**get_plan_purchases**](docs/AccountsApi.md#get_plan_purchases) | **GET** /api/accounts/plans/{planId}/purchases | Get Plan Purchases
*AccountsApi* | [**get_purchases**](docs/AccountsApi.md#get_purchases) | **GET** /api/accounts/purchases | Get User&#39;s Appstore Purchases.
*AppElementsApi* | [**commit_transaction**](docs/AppElementsApi.md#commit_transaction) | **POST** /api/appelements/d/{did}/w/{wid}/e/{eid}/transactions/{tid} | Commit Transaction
*AppElementsApi* | [**create7**](docs/AppElementsApi.md#create7) | **POST** /api/appelements/d/{did}/w/{wid} | Create Element.
*AppElementsApi* | [**create_reference1**](docs/AppElementsApi.md#create_reference1) | **POST** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references | Create Reference
*AppElementsApi* | [**delete_content1**](docs/AppElementsApi.md#delete_content1) | **DELETE** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/subelements/{sid} | Delete a Sub-element
*AppElementsApi* | [**delete_reference1**](docs/AppElementsApi.md#delete_reference1) | **DELETE** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid} | Delete Reference
*AppElementsApi* | [**get_history**](docs/AppElementsApi.md#get_history) | **GET** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/history | Get History
*AppElementsApi* | [**get_sub_element_content**](docs/AppElementsApi.md#get_sub_element_content) | **GET** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content | Get Content
*AppElementsApi* | [**get_subelement_ids**](docs/AppElementsApi.md#get_subelement_ids) | **GET** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/ids | Get Sub-element IDs
*AppElementsApi* | [**resolve_reference1**](docs/AppElementsApi.md#resolve_reference1) | **GET** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid} | Resolve Reference
*AppElementsApi* | [**start_transaction**](docs/AppElementsApi.md#start_transaction) | **POST** /api/appelements/d/{did}/w/{wid}/e/{eid}/transactions | Start Transaction
*AppElementsApi* | [**update5**](docs/AppElementsApi.md#update5) | **POST** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content | Update Element
*AppElementsApi* | [**update_reference1**](docs/AppElementsApi.md#update_reference1) | **POST** /api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid} | Update Reference
*DocumentsApi* | [**get14**](docs/DocumentsApi.md#get14) | **GET** /api/documents | 
*EndpointsApi* | [**get_endpoints**](docs/EndpointsApi.md#get_endpoints) | **GET** /api/endpoints | 
*PartsApi* | [**get_parts_wmv**](docs/PartsApi.md#get_parts_wmv) | **GET** /api/parts/d/{did}/{wvm}/{wvmid} | Get list of parts
*PartsApi* | [**update_parts_wmv**](docs/PartsApi.md#update_parts_wmv) | **POST** /api/parts/d/{did}/{wvm}/{wvmid} | Part metadata batch update.
*DefaultApi* | [**add_feature1**](docs/DefaultApi.md#add_feature1) | **POST** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/features | Add Feature
*DefaultApi* | [**create_part_studio**](docs/DefaultApi.md#create_part_studio) | **POST** /api/partstudios/d/{did}/w/{wid} | Create Part Studio
*DefaultApi* | [**export_ps1**](docs/DefaultApi.md#export_ps1) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/parasolid | Export Part Studio to Parasolid
*DefaultApi* | [**export_stl1**](docs/DefaultApi.md#export_stl1) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/stl | Export Part Studio to STL
*DefaultApi* | [**get_body_details2**](docs/DefaultApi.md#get_body_details2) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/bodydetails | Array of body information
*DefaultApi* | [**get_bounding_boxes2**](docs/DefaultApi.md#get_bounding_boxes2) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/boundingboxes | Mass properties of parts or a PartStudio.
*DefaultApi* | [**get_edges2**](docs/DefaultApi.md#get_edges2) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/tessellatededges | Tesselated edges from a PartStudio.
*DefaultApi* | [**get_faces2**](docs/DefaultApi.md#get_faces2) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/tessellatedfaces | Tesselated faces of the parts in the Part Studio.
*DefaultApi* | [**get_features**](docs/DefaultApi.md#get_features) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/features | Get Feature List
*DefaultApi* | [**get_mass_properties**](docs/DefaultApi.md#get_mass_properties) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/massproperties | Mass properties of parts or a PartStudio.
*DefaultApi* | [**get_named_views2**](docs/DefaultApi.md#get_named_views2) | **GET** /api/partstudios/d/{did}/e/{eid}/namedViews | Get Named Views
*DefaultApi* | [**get_open_api**](docs/DefaultApi.md#get_open_api) | **GET** /api/openapi | OpenAPI spec documentation for the Onshape REST API.
*DefaultApi* | [**get_shaded_views1**](docs/DefaultApi.md#get_shaded_views1) | **GET** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/shadedviews | Get Shaded Views
*DefaultApi* | [**get_translator_formats4**](docs/DefaultApi.md#get_translator_formats4) | **GET** /api/partstudios/d/{did}/w/{wid}/e/{eid}/translationformats | Get Translation Formats
*DefaultApi* | [**translate_format5**](docs/DefaultApi.md#translate_format5) | **POST** /api/partstudios/d/{did}/{wv}/{wvid}/e/{eid}/translations | Create Part Studio translation
*DefaultApi* | [**translate_ids1**](docs/DefaultApi.md#translate_ids1) | **POST** /api/partstudios/d/{did}/{wvm}/{wvmid}/e/{eid}/idtranslations | Id Translations


## Documentation For Models

 - [Address](docs/Address.md)
 - [ApiResponse](docs/ApiResponse.md)
 - [ApiResponses](docs/ApiResponses.md)
 - [BTAPIApplicationDeprecateParams](docs/BTAPIApplicationDeprecateParams.md)
 - [BTAPIApplicationParams](docs/BTAPIApplicationParams.md)
 - [BTAPIApplicationSummaryInfo](docs/BTAPIApplicationSummaryInfo.md)
 - [BTAPIDeveloperParams](docs/BTAPIDeveloperParams.md)
 - [BTAPIKeyParams](docs/BTAPIKeyParams.md)
 - [BTAPIPartnerParams](docs/BTAPIPartnerParams.md)
 - [BTAclParams](docs/BTAclParams.md)
 - [BTActionInfo](docs/BTActionInfo.md)
 - [BTAddFriendParams](docs/BTAddFriendParams.md)
 - [BTAddressInfo](docs/BTAddressInfo.md)
 - [BTAdminGroupParams](docs/BTAdminGroupParams.md)
 - [BTAdminRoleParams](docs/BTAdminRoleParams.md)
 - [BTAdminRolePermissionParams](docs/BTAdminRolePermissionParams.md)
 - [BTAdminTaskParams](docs/BTAdminTaskParams.md)
 - [BTAdminUserRoleParams](docs/BTAdminUserRoleParams.md)
 - [BTAgreementParams](docs/BTAgreementParams.md)
 - [BTApiKeyUpdateParams](docs/BTApiKeyUpdateParams.md)
 - [BTAppAssociativeDataParamsArray](docs/BTAppAssociativeDataParamsArray.md)
 - [BTAppElementChangeParams](docs/BTAppElementChangeParams.md)
 - [BTAppElementCommitTransactionParams](docs/BTAppElementCommitTransactionParams.md)
 - [BTAppElementContentDeltaInfo](docs/BTAppElementContentDeltaInfo.md)
 - [BTAppElementContentEntryInfo](docs/BTAppElementContentEntryInfo.md)
 - [BTAppElementContentInfo](docs/BTAppElementContentInfo.md)
 - [BTAppElementHistoryEntryInfo](docs/BTAppElementHistoryEntryInfo.md)
 - [BTAppElementHistoryInfo](docs/BTAppElementHistoryInfo.md)
 - [BTAppElementModifyInfo](docs/BTAppElementModifyInfo.md)
 - [BTAppElementParams](docs/BTAppElementParams.md)
 - [BTAppElementReferenceInfo](docs/BTAppElementReferenceInfo.md)
 - [BTAppElementReferenceParams](docs/BTAppElementReferenceParams.md)
 - [BTAppElementReferenceResolveInfo](docs/BTAppElementReferenceResolveInfo.md)
 - [BTAppElementStartTransactionParams](docs/BTAppElementStartTransactionParams.md)
 - [BTAppElementUpdateParams](docs/BTAppElementUpdateParams.md)
 - [BTAppViewParams](docs/BTAppViewParams.md)
 - [BTApplicationElementThumbnailParams](docs/BTApplicationElementThumbnailParams.md)
 - [BTApplicationElementThumbnailParamsArray](docs/BTApplicationElementThumbnailParamsArray.md)
 - [BTApproveTranslationDebugParams](docs/BTApproveTranslationDebugParams.md)
 - [BTAssemblyInstanceDefinitionParams](docs/BTAssemblyInstanceDefinitionParams.md)
 - [BTAssemblyTransformDefinitionParams](docs/BTAssemblyTransformDefinitionParams.md)
 - [BTAssemblyTransformedInstancesDefinitionParams](docs/BTAssemblyTransformedInstancesDefinitionParams.md)
 - [BTAssociativeDataParams](docs/BTAssociativeDataParams.md)
 - [BTAssociativeFieldParams](docs/BTAssociativeFieldParams.md)
 - [BTAutoPartNumberingSchemeParams](docs/BTAutoPartNumberingSchemeParams.md)
 - [BTBaseInfo](docs/BTBaseInfo.md)
 - [BTBelScriptLibraryVersion](docs/BTBelScriptLibraryVersion.md)
 - [BTBetaCapabilityAdminInfo](docs/BTBetaCapabilityAdminInfo.md)
 - [BTBetaCapabilityImportInfo](docs/BTBetaCapabilityImportInfo.md)
 - [BTBetaCapabilityInfo](docs/BTBetaCapabilityInfo.md)
 - [BTBetaCapabilityMetricsInfo](docs/BTBetaCapabilityMetricsInfo.md)
 - [BTBetaCapabilityParams](docs/BTBetaCapabilityParams.md)
 - [BTBetaCapabilitySummaryInfo](docs/BTBetaCapabilitySummaryInfo.md)
 - [BTBetaCapabilityUserInfo](docs/BTBetaCapabilityUserInfo.md)
 - [BTBillingAccountParams](docs/BTBillingAccountParams.md)
 - [BTBillingAllowedPlansInfo](docs/BTBillingAllowedPlansInfo.md)
 - [BTBillingPlanBatchParams](docs/BTBillingPlanBatchParams.md)
 - [BTBillingPlanInfo](docs/BTBillingPlanInfo.md)
 - [BTBillingPlanParams](docs/BTBillingPlanParams.md)
 - [BTBillingPlanSummaryInfo](docs/BTBillingPlanSummaryInfo.md)
 - [BTBoundingBox](docs/BTBoundingBox.md)
 - [BTBoundingBoxParams](docs/BTBoundingBoxParams.md)
 - [BTBrokenOutEndCondition](docs/BTBrokenOutEndCondition.md)
 - [BTBulkDocumentUpdateParams](docs/BTBulkDocumentUpdateParams.md)
 - [BTCacheInfo](docs/BTCacheInfo.md)
 - [BTCampaignParams](docs/BTCampaignParams.md)
 - [BTCapabilityCheckParams](docs/BTCapabilityCheckParams.md)
 - [BTCapabilityParams](docs/BTCapabilityParams.md)
 - [BTCapabilityRuleParams](docs/BTCapabilityRuleParams.md)
 - [BTCapableInfo](docs/BTCapableInfo.md)
 - [BTCardInfo](docs/BTCardInfo.md)
 - [BTCardParams](docs/BTCardParams.md)
 - [BTChangeContextParams](docs/BTChangeContextParams.md)
 - [BTCloudStorageAccountInfo](docs/BTCloudStorageAccountInfo.md)
 - [BTCloudStorageAccountListInfo](docs/BTCloudStorageAccountListInfo.md)
 - [BTCloudStorageObjectInfo](docs/BTCloudStorageObjectInfo.md)
 - [BTCloudStorageObjectListInfo](docs/BTCloudStorageObjectListInfo.md)
 - [BTCloudStorageProviderObjectInfo](docs/BTCloudStorageProviderObjectInfo.md)
 - [BTColorInfo](docs/BTColorInfo.md)
 - [BTColorParams](docs/BTColorParams.md)
 - [BTCommentAttachmentInfo](docs/BTCommentAttachmentInfo.md)
 - [BTCommentInfo](docs/BTCommentInfo.md)
 - [BTCommentNotificationParams](docs/BTCommentNotificationParams.md)
 - [BTCommentParams](docs/BTCommentParams.md)
 - [BTCommentSubscriptionParams](docs/BTCommentSubscriptionParams.md)
 - [BTCompanyActivateParams](docs/BTCompanyActivateParams.md)
 - [BTCompanyNoPublicDocumentParams](docs/BTCompanyNoPublicDocumentParams.md)
 - [BTCompanyParams](docs/BTCompanyParams.md)
 - [BTCompanyPoliciesParams](docs/BTCompanyPoliciesParams.md)
 - [BTCompanySummaryInfo](docs/BTCompanySummaryInfo.md)
 - [BTCompanyTransferParams](docs/BTCompanyTransferParams.md)
 - [BTCompanyUserParams](docs/BTCompanyUserParams.md)
 - [BTComponentUsagesSummary](docs/BTComponentUsagesSummary.md)
 - [BTConfigurationIdInfo](docs/BTConfigurationIdInfo.md)
 - [BTConfigurationInfo](docs/BTConfigurationInfo.md)
 - [BTConfigurationParams](docs/BTConfigurationParams.md)
 - [BTConnection](docs/BTConnection.md)
 - [BTCopyDocumentParams](docs/BTCopyDocumentParams.md)
 - [BTCopyElementParams](docs/BTCopyElementParams.md)
 - [BTCurveDescription](docs/BTCurveDescription.md)
 - [BTCustomPropertyDefinitionInfo](docs/BTCustomPropertyDefinitionInfo.md)
 - [BTCustomPropertyDefinitionParams](docs/BTCustomPropertyDefinitionParams.md)
 - [BTDBViewerCollectionConfig](docs/BTDBViewerCollectionConfig.md)
 - [BTDBViewerConfig](docs/BTDBViewerConfig.md)
 - [BTDBViewerQueryParams](docs/BTDBViewerQueryParams.md)
 - [BTDeviceInfo](docs/BTDeviceInfo.md)
 - [BTDeviceTokenParams](docs/BTDeviceTokenParams.md)
 - [BTDiffInfo](docs/BTDiffInfo.md)
 - [BTDiscountInfo](docs/BTDiscountInfo.md)
 - [BTDiscountParams](docs/BTDiscountParams.md)
 - [BTDocumentCheckAccessParams](docs/BTDocumentCheckAccessParams.md)
 - [BTDocumentElementInfo](docs/BTDocumentElementInfo.md)
 - [BTDocumentInfo](docs/BTDocumentInfo.md)
 - [BTDocumentLabelInfo](docs/BTDocumentLabelInfo.md)
 - [BTDocumentLabelParams](docs/BTDocumentLabelParams.md)
 - [BTDocumentMicroversionInfo](docs/BTDocumentMicroversionInfo.md)
 - [BTDocumentMigrateParams](docs/BTDocumentMigrateParams.md)
 - [BTDocumentOptionsParams](docs/BTDocumentOptionsParams.md)
 - [BTDocumentParams](docs/BTDocumentParams.md)
 - [BTDocumentProcessingInfo](docs/BTDocumentProcessingInfo.md)
 - [BTDocumentScope](docs/BTDocumentScope.md)
 - [BTDocumentSearchHitInfo](docs/BTDocumentSearchHitInfo.md)
 - [BTDocumentSearchParams](docs/BTDocumentSearchParams.md)
 - [BTDocumentSummaryInfo](docs/BTDocumentSummaryInfo.md)
 - [BTDocumentSummarySearchInfo](docs/BTDocumentSummarySearchInfo.md)
 - [BTDocumentVersionElementIds](docs/BTDocumentVersionElementIds.md)
 - [BTDocumentWithVersionAndElementId](docs/BTDocumentWithVersionAndElementId.md)
 - [BTDocumentWithVersionId](docs/BTDocumentWithVersionId.md)
 - [BTDrawingParams](docs/BTDrawingParams.md)
 - [BTESDocumentHit](docs/BTESDocumentHit.md)
 - [BTElementLocationParams](docs/BTElementLocationParams.md)
 - [BTElementParams](docs/BTElementParams.md)
 - [BTElementPropertiesParams](docs/BTElementPropertiesParams.md)
 - [BTElementRenameParams](docs/BTElementRenameParams.md)
 - [BTElementThumbnailDataParams](docs/BTElementThumbnailDataParams.md)
 - [BTEnterpriseReportParams](docs/BTEnterpriseReportParams.md)
 - [BTExportModelBodiesResponse](docs/BTExportModelBodiesResponse.md)
 - [BTExportModelBody](docs/BTExportModelBody.md)
 - [BTExportModelCoedge](docs/BTExportModelCoedge.md)
 - [BTExportModelEdge](docs/BTExportModelEdge.md)
 - [BTExportModelEdgeGeometry](docs/BTExportModelEdgeGeometry.md)
 - [BTExportModelFace](docs/BTExportModelFace.md)
 - [BTExportModelLoop](docs/BTExportModelLoop.md)
 - [BTExportModelParams](docs/BTExportModelParams.md)
 - [BTExportModelVertex](docs/BTExportModelVertex.md)
 - [BTExportTessellatedEdgesBody](docs/BTExportTessellatedEdgesBody.md)
 - [BTExportTessellatedEdgesEdge](docs/BTExportTessellatedEdgesEdge.md)
 - [BTExportTessellatedEdgesResponse](docs/BTExportTessellatedEdgesResponse.md)
 - [BTExportTessellatedFacesBody](docs/BTExportTessellatedFacesBody.md)
 - [BTExportTessellatedFacesFace](docs/BTExportTessellatedFacesFace.md)
 - [BTExportTessellatedFacesFacet](docs/BTExportTessellatedFacesFacet.md)
 - [BTExportTessellatedFacesResponse](docs/BTExportTessellatedFacesResponse.md)
 - [BTExtendTrialParams](docs/BTExtendTrialParams.md)
 - [BTExternalElementReferenceInfo](docs/BTExternalElementReferenceInfo.md)
 - [BTFSValue](docs/BTFSValue.md)
 - [BTFeatureDefinitionResponse](docs/BTFeatureDefinitionResponse.md)
 - [BTFeatureListResponse](docs/BTFeatureListResponse.md)
 - [BTFeatureScriptEvalCall](docs/BTFeatureScriptEvalCall.md)
 - [BTFeatureScriptEvalResponse](docs/BTFeatureScriptEvalResponse.md)
 - [BTFeatureState](docs/BTFeatureState.md)
 - [BTFolderInfo](docs/BTFolderInfo.md)
 - [BTFolderParams](docs/BTFolderParams.md)
 - [BTFriendInfo](docs/BTFriendInfo.md)
 - [BTFriendsFromIdsParams](docs/BTFriendsFromIdsParams.md)
 - [BTGlobalPermissionDefinitionsInfo](docs/BTGlobalPermissionDefinitionsInfo.md)
 - [BTGlobalPermissionInfo](docs/BTGlobalPermissionInfo.md)
 - [BTGlobalPermissionParams](docs/BTGlobalPermissionParams.md)
 - [BTGlobalTreeMagicNodeInfo](docs/BTGlobalTreeMagicNodeInfo.md)
 - [BTGlobalTreeNodeInfo](docs/BTGlobalTreeNodeInfo.md)
 - [BTGlobalTreeNodeInfoListBTGlobalTreeNodeInfo](docs/BTGlobalTreeNodeInfoListBTGlobalTreeNodeInfo.md)
 - [BTGlobalTreeNodeMoveParams](docs/BTGlobalTreeNodeMoveParams.md)
 - [BTGlobalTreeNodeOwnerParams](docs/BTGlobalTreeNodeOwnerParams.md)
 - [BTGlobalTreeNodeWithChildrenInfo](docs/BTGlobalTreeNodeWithChildrenInfo.md)
 - [BTGraphicsAppearance](docs/BTGraphicsAppearance.md)
 - [BTIdAndConfiguration](docs/BTIdAndConfiguration.md)
 - [BTIdTranslationInfo](docs/BTIdTranslationInfo.md)
 - [BTIdTranslationParams](docs/BTIdTranslationParams.md)
 - [BTIdTranslationResultInfo](docs/BTIdTranslationResultInfo.md)
 - [BTIdentity](docs/BTIdentity.md)
 - [BTIdentityInfo](docs/BTIdentityInfo.md)
 - [BTIdentityManagementParams](docs/BTIdentityManagementParams.md)
 - [BTIdentityParams](docs/BTIdentityParams.md)
 - [BTImportCloudObjectParams](docs/BTImportCloudObjectParams.md)
 - [BTImportForeignDataParams](docs/BTImportForeignDataParams.md)
 - [BTInAppMessageContent](docs/BTInAppMessageContent.md)
 - [BTInAppMessageContentItem](docs/BTInAppMessageContentItem.md)
 - [BTInAppMessageInfo](docs/BTInAppMessageInfo.md)
 - [BTInAppMessageParams](docs/BTInAppMessageParams.md)
 - [BTInsertionLocation](docs/BTInsertionLocation.md)
 - [BTInvitationParams](docs/BTInvitationParams.md)
 - [BTItemParams](docs/BTItemParams.md)
 - [BTLinkToLatestDocumentParams](docs/BTLinkToLatestDocumentParams.md)
 - [BTListResponseBTBetaCapabilitySummaryInfo](docs/BTListResponseBTBetaCapabilitySummaryInfo.md)
 - [BTListResponseBTBetaCapabilityUserInfo](docs/BTListResponseBTBetaCapabilityUserInfo.md)
 - [BTListResponseBTCloudStorageProviderObjectInfo](docs/BTListResponseBTCloudStorageProviderObjectInfo.md)
 - [BTListResponseBTFriendInfo](docs/BTListResponseBTFriendInfo.md)
 - [BTListResponseBTInAppMessageInfo](docs/BTListResponseBTInAppMessageInfo.md)
 - [BTListResponseBTPurchaseInfo](docs/BTListResponseBTPurchaseInfo.md)
 - [BTListResponseBTStandardContentHierarchyInfo](docs/BTListResponseBTStandardContentHierarchyInfo.md)
 - [BTListResponseBTSystemConfigInfo](docs/BTListResponseBTSystemConfigInfo.md)
 - [BTLocationInfo](docs/BTLocationInfo.md)
 - [BTLoginParams](docs/BTLoginParams.md)
 - [BTLoginTotpParams](docs/BTLoginTotpParams.md)
 - [BTMFeature](docs/BTMFeature.md)
 - [BTMImport](docs/BTMImport.md)
 - [BTMParameter](docs/BTMParameter.md)
 - [BTMSuppressionState](docs/BTMSuppressionState.md)
 - [BTMassPropResponse](docs/BTMassPropResponse.md)
 - [BTMassProperties](docs/BTMassProperties.md)
 - [BTMatchingStandardContentHierarchyInfo](docs/BTMatchingStandardContentHierarchyInfo.md)
 - [BTMaterialParams](docs/BTMaterialParams.md)
 - [BTMaterialPropertyParams](docs/BTMaterialPropertyParams.md)
 - [BTMetadataEnumValueInfo](docs/BTMetadataEnumValueInfo.md)
 - [BTMetadataPropertyConfigParams](docs/BTMetadataPropertyConfigParams.md)
 - [BTMetadataPropertyInfo](docs/BTMetadataPropertyInfo.md)
 - [BTMetadataPropertyParams](docs/BTMetadataPropertyParams.md)
 - [BTMetadataPropertyUiHintsInfo](docs/BTMetadataPropertyUiHintsInfo.md)
 - [BTMetadataPropertyValidatorInfo](docs/BTMetadataPropertyValidatorInfo.md)
 - [BTMetadataSchemaParams](docs/BTMetadataSchemaParams.md)
 - [BTMetricParams](docs/BTMetricParams.md)
 - [BTMetricsListParams](docs/BTMetricsListParams.md)
 - [BTMicroversionId](docs/BTMicroversionId.md)
 - [BTMobileNotificationParams](docs/BTMobileNotificationParams.md)
 - [BTModelBodyParams](docs/BTModelBodyParams.md)
 - [BTModelElementParams](docs/BTModelElementParams.md)
 - [BTModelFormatInfo](docs/BTModelFormatInfo.md)
 - [BTModelTessellationParams](docs/BTModelTessellationParams.md)
 - [BTMoveElementInfo](docs/BTMoveElementInfo.md)
 - [BTMoveElementParams](docs/BTMoveElementParams.md)
 - [BTNameValuePair](docs/BTNameValuePair.md)
 - [BTNamedViewInfo](docs/BTNamedViewInfo.md)
 - [BTNamedViewsInfo](docs/BTNamedViewsInfo.md)
 - [BTNextPartNumberParam](docs/BTNextPartNumberParam.md)
 - [BTNextPartNumbersParam](docs/BTNextPartNumbersParam.md)
 - [BTNextRevisionParams](docs/BTNextRevisionParams.md)
 - [BTNodeReference](docs/BTNodeReference.md)
 - [BTNodeStatus](docs/BTNodeStatus.md)
 - [BTNotice](docs/BTNotice.md)
 - [BTNotificationDebugParams](docs/BTNotificationDebugParams.md)
 - [BTNotificationParams](docs/BTNotificationParams.md)
 - [BTObjectId](docs/BTObjectId.md)
 - [BTOccurrence](docs/BTOccurrence.md)
 - [BTOwnerInfo](docs/BTOwnerInfo.md)
 - [BTPDMMetadataParams](docs/BTPDMMetadataParams.md)
 - [BTPLiteralString](docs/BTPLiteralString.md)
 - [BTPModuleId](docs/BTPModuleId.md)
 - [BTPNode](docs/BTPNode.md)
 - [BTPSpace](docs/BTPSpace.md)
 - [BTPartAppearanceInfo](docs/BTPartAppearanceInfo.md)
 - [BTPartAppearanceParams](docs/BTPartAppearanceParams.md)
 - [BTPartIdParams](docs/BTPartIdParams.md)
 - [BTPartMaterialInfo](docs/BTPartMaterialInfo.md)
 - [BTPartMaterialPropertyInfo](docs/BTPartMaterialPropertyInfo.md)
 - [BTPartMetadataInfo](docs/BTPartMetadataInfo.md)
 - [BTPartQueryParams](docs/BTPartQueryParams.md)
 - [BTPasswordResetParams](docs/BTPasswordResetParams.md)
 - [BTPaymentTypeParams](docs/BTPaymentTypeParams.md)
 - [BTPermissionSet](docs/BTPermissionSet.md)
 - [BTPlanSubscriberInfo](docs/BTPlanSubscriberInfo.md)
 - [BTProjectInfo](docs/BTProjectInfo.md)
 - [BTProjectParams](docs/BTProjectParams.md)
 - [BTPropertyValueParam](docs/BTPropertyValueParam.md)
 - [BTPurchaseInfo](docs/BTPurchaseInfo.md)
 - [BTPurchaseParams](docs/BTPurchaseParams.md)
 - [BTPurchaseUserInfo](docs/BTPurchaseUserInfo.md)
 - [BTPurchaseUserParams](docs/BTPurchaseUserParams.md)
 - [BTQueryRevisionParams](docs/BTQueryRevisionParams.md)
 - [BTRbacPermissionSchemeEntryParams](docs/BTRbacPermissionSchemeEntryParams.md)
 - [BTRbacPermissionSchemeInfo](docs/BTRbacPermissionSchemeInfo.md)
 - [BTRbacPermissionSchemeListInfo](docs/BTRbacPermissionSchemeListInfo.md)
 - [BTRbacPermissionSchemeParams](docs/BTRbacPermissionSchemeParams.md)
 - [BTRbacRoleInfo](docs/BTRbacRoleInfo.md)
 - [BTRbacRoleParams](docs/BTRbacRoleParams.md)
 - [BTReleasePackageInfo](docs/BTReleasePackageInfo.md)
 - [BTReleasePackageItem](docs/BTReleasePackageItem.md)
 - [BTReleasePackageItemError](docs/BTReleasePackageItemError.md)
 - [BTReleasePackageItemInfo](docs/BTReleasePackageItemInfo.md)
 - [BTReleasePackageItemParams](docs/BTReleasePackageItemParams.md)
 - [BTReleasePackageParams](docs/BTReleasePackageParams.md)
 - [BTReleasePackageWorkflowChangeParams](docs/BTReleasePackageWorkflowChangeParams.md)
 - [BTRepairContextParams](docs/BTRepairContextParams.md)
 - [BTRevisionCustomData](docs/BTRevisionCustomData.md)
 - [BTRevisionParams](docs/BTRevisionParams.md)
 - [BTRevisionRuleInfo](docs/BTRevisionRuleInfo.md)
 - [BTRevisionRuleParams](docs/BTRevisionRuleParams.md)
 - [BTRootDiffInfo](docs/BTRootDiffInfo.md)
 - [BTSeatsParams](docs/BTSeatsParams.md)
 - [BTSectionPlaneInfo](docs/BTSectionPlaneInfo.md)
 - [BTSendGridDeliveryEventParams](docs/BTSendGridDeliveryEventParams.md)
 - [BTSettingInfo](docs/BTSettingInfo.md)
 - [BTSettingParam](docs/BTSettingParam.md)
 - [BTShadedRenderDocumentResponse](docs/BTShadedRenderDocumentResponse.md)
 - [BTShareEntryParams](docs/BTShareEntryParams.md)
 - [BTShareParams](docs/BTShareParams.md)
 - [BTSimpleInfo](docs/BTSimpleInfo.md)
 - [BTStandardContentCustomParameterDefinition](docs/BTStandardContentCustomParameterDefinition.md)
 - [BTStandardContentCustomParameterDefinitionId](docs/BTStandardContentCustomParameterDefinitionId.md)
 - [BTStandardContentCustomParameterParams](docs/BTStandardContentCustomParameterParams.md)
 - [BTStandardContentFindUsageParams](docs/BTStandardContentFindUsageParams.md)
 - [BTStandardContentHierarchy](docs/BTStandardContentHierarchy.md)
 - [BTStandardContentHierarchyInfo](docs/BTStandardContentHierarchyInfo.md)
 - [BTStandardContentHierarchyParams](docs/BTStandardContentHierarchyParams.md)
 - [BTStandardContentHierarchyRenameParams](docs/BTStandardContentHierarchyRenameParams.md)
 - [BTStandardContentParameterDefinition](docs/BTStandardContentParameterDefinition.md)
 - [BTStandardContentParams](docs/BTStandardContentParams.md)
 - [BTStandardContentSetRunVersionsParams](docs/BTStandardContentSetRunVersionsParams.md)
 - [BTStandardContentUsageSummary](docs/BTStandardContentUsageSummary.md)
 - [BTStartEditInContextParams](docs/BTStartEditInContextParams.md)
 - [BTSubstituteApproverParams](docs/BTSubstituteApproverParams.md)
 - [BTSurfaceDescription](docs/BTSurfaceDescription.md)
 - [BTSurveyResponseParams](docs/BTSurveyResponseParams.md)
 - [BTSystemConfigInfo](docs/BTSystemConfigInfo.md)
 - [BTTagParams](docs/BTTagParams.md)
 - [BTTeamInfo](docs/BTTeamInfo.md)
 - [BTTeamMemberParams](docs/BTTeamMemberParams.md)
 - [BTTeamParams](docs/BTTeamParams.md)
 - [BTTeamSummaryInfo](docs/BTTeamSummaryInfo.md)
 - [BTThumbnailInfo](docs/BTThumbnailInfo.md)
 - [BTThumbnailSizeInfo](docs/BTThumbnailSizeInfo.md)
 - [BTToolTreeParams](docs/BTToolTreeParams.md)
 - [BTToolTreeUpdateParams](docs/BTToolTreeUpdateParams.md)
 - [BTTranslateFormatParams](docs/BTTranslateFormatParams.md)
 - [BTTranslateInternalParams](docs/BTTranslateInternalParams.md)
 - [BTTranslationRequestInfo](docs/BTTranslationRequestInfo.md)
 - [BTUniqueDocumentItemParams](docs/BTUniqueDocumentItemParams.md)
 - [BTUpdateDocumentThumbnailParams](docs/BTUpdateDocumentThumbnailParams.md)
 - [BTUpdateElementThumbnailParams](docs/BTUpdateElementThumbnailParams.md)
 - [BTUpdateExternalReferenceParams](docs/BTUpdateExternalReferenceParams.md)
 - [BTUpdateInContextParams](docs/BTUpdateInContextParams.md)
 - [BTUpdateRbacRoleParams](docs/BTUpdateRbacRoleParams.md)
 - [BTUpdateReferenceParams](docs/BTUpdateReferenceParams.md)
 - [BTUpdateReleasePackageParams](docs/BTUpdateReleasePackageParams.md)
 - [BTUpdateVersionThumbnailParams](docs/BTUpdateVersionThumbnailParams.md)
 - [BTUpgradeOnDemandParams](docs/BTUpgradeOnDemandParams.md)
 - [BTUploadParams](docs/BTUploadParams.md)
 - [BTUploadStateParams](docs/BTUploadStateParams.md)
 - [BTUserActivationParams](docs/BTUserActivationParams.md)
 - [BTUserAgentVersion](docs/BTUserAgentVersion.md)
 - [BTUserAppSettingsInfo](docs/BTUserAppSettingsInfo.md)
 - [BTUserAppSettingsParams](docs/BTUserAppSettingsParams.md)
 - [BTUserBasicSummaryInfo](docs/BTUserBasicSummaryInfo.md)
 - [BTUserEmailParams](docs/BTUserEmailParams.md)
 - [BTUserEmailVerifyParams](docs/BTUserEmailVerifyParams.md)
 - [BTUserNotificationPrefLevelsInfo](docs/BTUserNotificationPrefLevelsInfo.md)
 - [BTUserNotificationPrefParams](docs/BTUserNotificationPrefParams.md)
 - [BTUserParams](docs/BTUserParams.md)
 - [BTUserSettingsParams](docs/BTUserSettingsParams.md)
 - [BTUserSummaryInfo](docs/BTUserSummaryInfo.md)
 - [BTUserTotpParams](docs/BTUserTotpParams.md)
 - [BTUserUpdateParams](docs/BTUserUpdateParams.md)
 - [BTUserUpdateSpecsParams](docs/BTUserUpdateSpecsParams.md)
 - [BTUserUsagesSummary](docs/BTUserUsagesSummary.md)
 - [BTUserWebPreferencesParams](docs/BTUserWebPreferencesParams.md)
 - [BTVector2d](docs/BTVector2d.md)
 - [BTVector3d](docs/BTVector3d.md)
 - [BTVersionInfo](docs/BTVersionInfo.md)
 - [BTVersionOrWorkspaceInfo](docs/BTVersionOrWorkspaceInfo.md)
 - [BTVersionOrWorkspaceParams](docs/BTVersionOrWorkspaceParams.md)
 - [BTViewDataInfo](docs/BTViewDataInfo.md)
 - [BTViewDataParams](docs/BTViewDataParams.md)
 - [BTWebClientCapabilitiesParams](docs/BTWebClientCapabilitiesParams.md)
 - [BTWebRendererPerformanceMeasurementParams](docs/BTWebRendererPerformanceMeasurementParams.md)
 - [BTWebhookOptions](docs/BTWebhookOptions.md)
 - [BTWebhookParams](docs/BTWebhookParams.md)
 - [BTWorkflowInfo](docs/BTWorkflowInfo.md)
 - [BTWorkflowStateInfo](docs/BTWorkflowStateInfo.md)
 - [BTWorkspaceInfo](docs/BTWorkspaceInfo.md)
 - [BTWorkspacePartParams](docs/BTWorkspacePartParams.md)
 - [BodyPart](docs/BodyPart.md)
 - [BodyPartHeaders](docs/BodyPartHeaders.md)
 - [BodyPartMediaType](docs/BodyPartMediaType.md)
 - [Callback](docs/Callback.md)
 - [Card](docs/Card.md)
 - [ClientLogEntry](docs/ClientLogEntry.md)
 - [CloudObjectPathSegment](docs/CloudObjectPathSegment.md)
 - [Components](docs/Components.md)
 - [ConfigurationEntry](docs/ConfigurationEntry.md)
 - [ConfigurationInfoEntry](docs/ConfigurationInfoEntry.md)
 - [Contact](docs/Contact.md)
 - [Content](docs/Content.md)
 - [ContentDisposition](docs/ContentDisposition.md)
 - [ContentItem](docs/ContentItem.md)
 - [Coupon](docs/Coupon.md)
 - [Customer](docs/Customer.md)
 - [CustomerCardCollection](docs/CustomerCardCollection.md)
 - [CustomerSubscriptionCollection](docs/CustomerSubscriptionCollection.md)
 - [Definition](docs/Definition.md)
 - [Discount](docs/Discount.md)
 - [Discriminator](docs/Discriminator.md)
 - [Encoding](docs/Encoding.md)
 - [Entry](docs/Entry.md)
 - [Example](docs/Example.md)
 - [ExternalAccount](docs/ExternalAccount.md)
 - [ExternalAccountCollection](docs/ExternalAccountCollection.md)
 - [ExternalDocumentation](docs/ExternalDocumentation.md)
 - [FormDataBodyPart](docs/FormDataBodyPart.md)
 - [FormDataContentDisposition](docs/FormDataContentDisposition.md)
 - [FormDataMultiPart](docs/FormDataMultiPart.md)
 - [GlobalPermissionInfo](docs/GlobalPermissionInfo.md)
 - [Header](docs/Header.md)
 - [Info](docs/Info.md)
 - [Item](docs/Item.md)
 - [JsonNode](docs/JsonNode.md)
 - [LevelInfo](docs/LevelInfo.md)
 - [License](docs/License.md)
 - [Link](docs/Link.md)
 - [MediaType](docs/MediaType.md)
 - [Message](docs/Message.md)
 - [MessageBodyWorkers](docs/MessageBodyWorkers.md)
 - [MultiPart](docs/MultiPart.md)
 - [NextCharge](docs/NextCharge.md)
 - [NextRecurringCharge](docs/NextRecurringCharge.md)
 - [OAuthFlow](docs/OAuthFlow.md)
 - [OAuthFlowScopes](docs/OAuthFlowScopes.md)
 - [OAuthFlows](docs/OAuthFlows.md)
 - [OpenAPI](docs/OpenAPI.md)
 - [Operation](docs/Operation.md)
 - [OperationResponses](docs/OperationResponses.md)
 - [Parameter](docs/Parameter.md)
 - [ParameterizedHeader](docs/ParameterizedHeader.md)
 - [PathItem](docs/PathItem.md)
 - [PathSegment](docs/PathSegment.md)
 - [Paths](docs/Paths.md)
 - [Plan](docs/Plan.md)
 - [ProratedCharges](docs/ProratedCharges.md)
 - [RequestBody](docs/RequestBody.md)
 - [RequestOptions](docs/RequestOptions.md)
 - [RoleMapEntry](docs/RoleMapEntry.md)
 - [Schema](docs/Schema.md)
 - [Scopes](docs/Scopes.md)
 - [SecurityRequirement](docs/SecurityRequirement.md)
 - [SecurityScheme](docs/SecurityScheme.md)
 - [Server](docs/Server.md)
 - [ServerVariable](docs/ServerVariable.md)
 - [ServerVariables](docs/ServerVariables.md)
 - [ShippingDetails](docs/ShippingDetails.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionItem](docs/SubscriptionItem.md)
 - [SubscriptionItemCollection](docs/SubscriptionItemCollection.md)
 - [Tag](docs/Tag.md)
 - [ThreeDSecure](docs/ThreeDSecure.md)
 - [TransformGroup](docs/TransformGroup.md)
 - [UpdateParams](docs/UpdateParams.md)
 - [VersionSpecs](docs/VersionSpecs.md)
 - [XML](docs/XML.md)


## Documentation For Authorization


## ApiKey

- **Type**: API key
- **API key parameter name**: ApiKey
- **Location**: HTTP header

## OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://oauth.onshape.com/oauth/authorize
- **Scopes**: 
 - **OAuth2Internal**: Application is Onshape Internal
 - **OAuth2ReadPII**: Application can read your profile information
 - **OAuth2Read**: Application can read your documents
 - **OAuth2Write**: Application can write to your documents
 - **OAuth2Delete**: Application can delete your documents and workspaces
 - **OAuth2Purchase**: Application can request purchases on your behalf
 - **OAuth2Share**: Application can share and unshare documents on your behalf


## Author

api-support@onshape.zendesk.com


